cancel method

  1. @override
void cancel()
override

Cancels the timer. An empty timer can be canceled as well.

Once a Timer has been canceled, the callback function will not be called by the timer. Calling cancel more than once on a Timer is allowed, and will have no further effect.

Implementation

@override
void cancel() {
  _isCanceled = true;
  final timer = _timer;
  if (timer == null) {
    return;
  }
  timer.cancel();
}